function [rrscale,xxt1,xxt2,xxt3]=modeltest(plshape);
%% This function reproduces the model tests shown in JMR paper.
%%  (JMR 172 (2005) p279)
%% ==> modeltest(CASE);
%% where CASE can be either of the followinfs:
%%      'bimodal' or 'box_like'
%%
%% e.g. modeltest('bimodal');
%%
%%
%% YWC 2005
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Parameters
dpts=150; tdpts=300; rmin=15; rmax=60; tint=6;
switch lower(plshape)
    case ('bimodal')
        [A,b_bar,x] = twog(tdpts,dpts,tint,rmin,rmax);
    case ('box_like')
        [A,b_bar,x] = box_shape(tdpts,dpts,tint,rmin,rmax);
end
randn('seed',41997);
e = 2.0e-2*randn(size(b_bar)); b = b_bar + e;
[m,n]=size(b_bar); snr(1)=1/(norm(b_bar-b)/sqrt(m));
[L,W]=get_l(dpts,1); 
[U,sm,X,V] = cgsvd(A,L);
subplot(3,2,1);lambda_l = l_curve(U,sm,b);
set(gca,'position',[0.1 0.67 0.40 0.28]);xlabel(' ');ylabel(' ');
x_tikh_l   = tikhonov(U,sm,X,b,lambda_l);
xxt1=x_tikh_l;

e = 0.6e-2*randn(size(b_bar)); b = b_bar + e;
snr(2)=1/(norm(b_bar-b)/sqrt(m));
subplot(3,2,3);lambda_l = l_curve(U,sm,b);
set(gca,'position',[0.1 0.36 0.40 0.28]);xlabel(' ');
x_tikh_l   = tikhonov(U,sm,X,b,lambda_l);
xxt2=x_tikh_l;

e = 1e-3*randn(size(b_bar)); b = b_bar + e;
snr(3)=1/(norm(b_bar-b)/sqrt(m));
subplot(3,2,5);lambda_l = l_curve(U,sm,b);
set(gca,'position',[0.1 0.05 0.40 0.28]);ylabel(' ');
x_tikh_l   = tikhonov(U,sm,X,b,lambda_l);
xxt3=x_tikh_l;

dispp=['SNR = ',num2str(snr)];
disp(dispp);
disp(' ');


%Plot the estimate and exact solutions
rrscale=rmin:(rmax-rmin)/(dpts-1):(rmax-rmin)/(dpts-1)*(dpts-1)+rmin;
%convert to nm
rrscale=rrscale/10;
rmin=rmin/10;rmax=rmax/10;
%%
subplot(3,2,2)
plot(rrscale,xxt1,rrscale,x,'-.');
set(gca,'position',[0.56 0.67 0.41 0.28]);
ymaxy=max(max([xxt1,x]));
yminy=min(min([xxt1,x]));
axis([rmin,rmax yminy ymaxy]);
ylabel('P(r)');set(gca,'ytick',[ ]);

subplot(3,2,4)
plot(rrscale,xxt2,rrscale,x,'-.');
set(gca,'position',[0.56 0.36 0.41 0.28]);
axis([rmin,rmax yminy ymaxy]);
ylabel('P(r)');set(gca,'ytick',[ ]);

subplot(3,2,6)
plot(rrscale,xxt3,rrscale,x,'-.');
set(gca,'position',[0.56 0.05 0.41 0.28]);
axis([rmin,rmax yminy ymaxy]);
xlabel('r,  [nm]'); ylabel('P(r)');set(gca,'ytick',[ ]);

